@@ -164,7 +164,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
         if is_lyric_ver2 and (comp.type == "lyric" or comp.type == "mix_lyric"):
             audio_compilation_path = comp.get_audio()
             lyric_comp = comp
-            if deezer_artist_id and f"{deezer_artist_id}".isnumeric() and int(deezer_artist_id) < 907996688:
+            if deezer_artist_id and f"{deezer_artist_id}".isnumeric() and int(deezer_artist_id) < 977996688:
                 audio_compilation_path = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, outro_claim_topic,
                                                                audio_compilation_path)
             continue
@@ -225,7 +225,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     logger = MyBarLogger(job_id, mf_server)
     if is_lyric_ver2 and is_lyric:
         is_compilation = True
-
+    tmp_path_maked_loop=None
     if not is_music:
         #make Lyric
         if max_duration <= 0:
@@ -295,7 +295,8 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     path_video = merge_intro_outro(path_video, introPath, outroPath)
     for comp in arr_comps:
         comp.close()
-    utils.remove(tmp_path_maked_loop)
+    if tmp_path_maked_loop:
+        utils.remove(tmp_path_maked_loop)
 
     return path_video
 
